Changelog
=========

Version 0.2
-----------

* the UrlArchiver class (and it's descendants, UrlDumper and S3Dumper) now accepts a list of (url, path) tuples instead of just a list of URLs (which is now deprecated)
